//
//  MBAnnotation.h
//  MBMapKit
//
//  Copyright 2011 Mapbar Inc. All rights reserved.
//

#import <CoreGraphics/CoreGraphics.h>
#import <CoreLocation/CoreLocation.h>
#import <Foundation/Foundation.h>

/** @protocol MBAnnotation
 *
 *  @brief
 *      MBAnnotation 协议用于给地图视图提供标注相关的信息。要使用本协议，你可以在任何存储或表示标注数据的自定义对象中采用它。
 *      然后每个对象作为一个简单的地图标注信息源服务并提供关键信息，例如标注在地图中的位置。
 *      \n标注对象并不给标注提供视觉展示，但一般协助（联合地图视图的委托）创建适当的 MBAnnotationView 对象来处理标注的显示。
 *      \n对象采用本协议必须实现 coordinate 属性。本协议的其它方法为可选。
 */
@protocol MBAnnotation <NSObject>

/** @property   coordinate
 *
 *  @brief  标注的中心点（指定为一个地图坐标）
 */
@property (nonatomic, readonly) CLLocationCoordinate2D coordinate;

@optional

/** 
 *
 *  @brief  返回包含标注标题的字符串。
 *  @return 标题字符串。
 *  @note   
 *      虽然本方法的实现是可选的，如果你希望标注在你的地图视图中可选，你需要实现本方法。字符串将显示在关联标注视图的弹出气泡中。
 */
- (NSString *)title;

/** 
 *
 *  @brief  返回包含标注副标题的字符串。
 *  @return 副标题字符串。
 *  @note   
 *      字符串将显示在关联标注视图的弹出气泡中。
 */
- (NSString *)subtitle;

/**
 *
 *  @brief  设置标注新的中心点。
 *  @param  newCoordinate   标注新的中心点。
 *  @note  
 *      标注支持拖动的情况下需要实现本方法来更新标注的位置。
 */
- (void)setCoordinate:(CLLocationCoordinate2D)newCoordinate;

@end
