//
//  MBPlacemark.h
//  MBMapKit
//
//  Copyright 2011 Mapbar Inc. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <CoreLocation/CoreLocation.h>
#import "MBAnnotation.h"

/** @interface MBPlacemark
 *
 *  @brief
 *      MBPlavemark对象存储兴趣点数据给点的经度和维度。兴趣点数据包含了与指定坐标关联的省份，城市和街道等信息。兴趣点对象
 *      一般由 MBReverseGeocoder 生成，你也可以自己创建。
 *      \n兴趣点也是一个标注并遵从 MBAnnotation 协议，标注的属性及方法包含了兴趣点的坐标及其它信息。因为它们是标注，你可
 *      以把它们直接加到地图视图中。
 */
@interface MBPlacemark : NSObject <MBAnnotation>{
@private
    NSDictionary *_addressDictionary;
    CLLocationCoordinate2D _coordinate;
}


/** 
 *
 *  @brief  用指定的坐标和地址字典初始化并返回兴趣点对象。
 *  @param  coordinate  与兴趣点关联的地图坐标。
 *  @param  addressDictionary   兴趣点的地址数据字典，字典的key为{"省"，"市"，"区"，"poi方向"，"距离"，"类型"，
 *                              "道路名称，"兴趣点城市，"poi名字"}，value数据类型为NSString。
 *  @return 初始化的MBPlacemark对象.
 *  @note 
 *      当你已经有地址的信息时可以手动创建兴趣点对象的实体，创建兴趣点对象可以避免reverse geocoder对象查询同样的信息。
 */
- (id)initWithCoordinate:(CLLocationCoordinate2D)coordinate
       addressDictionary:(NSDictionary *)addressDictionary;

/** @property   addressDictionary
 *
 *  @brief  包含兴趣点key及value的地址数据字典。
 */
@property (nonatomic, readonly) NSDictionary *addressDictionary;

/** @property   province
 *
 *  @brief  兴趣点所在省份 
 */
@property (nonatomic, readonly) NSString *province; //eg.广东省

/** @property   city
 *  
 *  @brief  兴趣点所在城市 
 */
@property (nonatomic, readonly) NSString *city;//eg.北京市

/** @property   district
 *  
 *  @brief  兴趣点所在区 
 */
@property (nonatomic, readonly) NSString *district; // eg.海淀区

/** @property   POIDirection
 *
 *  @brief  兴趣点所在方向 
 */
@property (nonatomic, readonly) NSString *POIDirection; //eg.西南

/** @property   distance
 *  
 *  @brief  兴趣点距离 
 */
@property (nonatomic, readonly) NSString *distance; //eg.0

/** @property   POIType
 *
 *  @brief  兴趣点类型 
 */
@property (nonatomic, readonly) NSString *POIType;//eg.饭店

/** @property   POIStreet
 *
 *  @brief  兴趣点道路名称
 */
@property (nonatomic, readonly) NSString *POIStreet;//eg.长安街

/** @property   POICity
 *
 *  @brief  兴趣点城市
 */
@property (nonatomic, readonly) NSString *POICity;//eg.北京

/** @property   POIName
 *
 *  @brief  兴趣点名字
 */
@property (nonatomic, readonly) NSString *POIName;//eg.天安门

@end