//
//  MBPolyline.h
//  MBMapKit
//
//  Copyright 2011 Mapbar Inc. All rights reserved.
//

#import "MBMultiPoint.h"
#import "MBOverlay.h"

/** @interface MBPolyline
 *
 *  @brief
 *      MBPolyline类表示一个或多个点组成的形状，它用于定义连结的线段。端点的按点数组中的顺序点对点连结。第一个点和最后一个
 *      点没有互相连结。
 */
@interface MBPolyline : MBMultiPoint <MBOverlay>

/**
 *
 *  @brief  使用指定的地图点集合创建并返回MBPolyline对象。
 *  @param  points  定义这个形状的地图点数组。这个数值的数据将被拷贝到新的对象中。
 *  @param  count   \e points 数组中项目的数量。
 *  @return 一个新的多线段对象。
 */
+ (MBPolyline *)polylineWithPoints:(MBMapPoint *)points count:(NSUInteger)count;

/**
 *
 *  @brief  使用指定的坐标点集合创建并返回MBPolyline对象。
 *  @param  coords  定义这个形状的坐标点数组。这个数值的数据将被拷贝到新的对象中。
 *  @param  count   \e coords 数组中项目的数量。
 *  @return 一个新的多线段对象。

 */
+ (MBPolyline *)polylineWithCoordinates:(CLLocationCoordinate2D *)coords count:(NSUInteger)count;

@end

