//
//  MBSearch.h
//  MBMapkit_library
//
//  Created by 张嘉伟 on 11-10-26.
//  Copyright 2011 Mapbar Inc. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <CoreLocation/CoreLocation.h>

#import "MBDirectionsOptions.h"
#import "MBSuggestResult.h"
#import "MBRouteSuggestResult.h"
#import "MBPoiResult.h"
#import "MBBusResult.h"
#import "MBDriveResult.h"
#import "MBWalkResult.h"
#import "MBTransitResult.h"

@class MBNetService;
@protocol MBSearchDelegate;

@interface MBSearch : NSObject
{
    MBNetService *_netService;
    id <MBSearchDelegate> _delegate;
    NSTimeInterval _timeoutInterval;
    NSString *_city;
    CLLocationCoordinate2D _center;
    NSUInteger _pageCount;
    NSUInteger _pageNumber;
}

@property(nonatomic, assign) id<MBSearchDelegate> delegate;

/** @property   timeoutInterval
 * 
 *  @brief  超时时间(秒)
 */
@property(nonatomic, readwrite) NSTimeInterval timeoutInterval;

/** @property   city
 * 
 *  @brief  搜索限定城市
 */
@property(nonatomic,copy) NSString* city;

/** @property   city
 * 
 *  @brief  搜索限定城市
 */
@property(nonatomic, assign) CLLocationCoordinate2D center;

/** @property   city
 * 
 *  @brief  搜索限定城市
 */
@property(nonatomic, readwrite) NSUInteger pageCount;

/**
 *
 *  @brief  根据输入给出建议关键词
 *  @param  keyword 关键词 required
 *  @param  city    城市 required
 *  @param  count   返回建议关键词数量 required
 *  @note   
 *      使用委托调用search: didReceivedSuggestResult:获得对应的结果
 */
- (void)suggestKeyword:(NSString*)keyword inCity:(NSString*)city  count:(NSUInteger)count;

/**
 *
 *  @brief  根据输入给出建议路线关键词
 *  @param  keyword 关键词 required
 *  @param  city    城市 required
 *  @param  pageNumger  页码(从1开始) required
 *  @note   使用委托调用search: didReceivedRouteSuggestResult:获得对应的结果
 *      
 */
- (void)routeSuggetKeyword:(NSString *)keyword inCity:(NSString *)city pageNumber:(NSUInteger)pageNumber;

/**
 *
 *  @brief  搜索关键词关联的POI点
 *  @param  keyword 关键词 required
 *  @param  city    城市 required
 *  @param  type    poi类型 optional
 *  @param  pageNumger  页码页码(从1开始) required
 *  @note   使用委托调用search: didReceivedPoiResult:获得对应的结果
 *      
 */
- (void)PoisWithKeyword:(NSString *)keyword inCity:(NSString *)city pageNumber:(NSUInteger)pageNumber;

/**
 *
 *  @brief  搜索关键词关联的POI点
 *  @param  keyword 关键词 optional
 *  @param  center    中心 required
 *  @param  type    poi类型 optional
 *  @param  pageNumger  页码(从1开始) required
 *  @note   关键词和类型必须有一个有效参数
 *          使用委托调用search: didReceivedPoiResult:获得对应的结果
 *      
 */
- (void)PoisAroundCenter:(CLLocationCoordinate2D)center withKeyword:(NSString *)keyword ofType:(NSString *)type pageNumber:(NSUInteger) pageNumber;

/**
 *
 *  @brief  搜索关键词关联的公交站点
 *  @param  keyword 关键词
 *  @param  city    城市
 *  @param  pageNumger  页码
 *  @note   使用委托调用search: didReceivedBusStationResult:获得对应的结果
 *      
 */
- (void)busStationsWithKeyword:(NSString *)keyword inCity:(NSString *)city pageNumber:(NSUInteger)pageNumber;

/**
 *
 *  @brief  搜索公交站点的详细信息
 *  @param  searchString 有MBBusStation中的searchString属性
 *  @note   使用委托调用search: didReceivedBusStationDetailResult:获得对应的结果
 *      
 */
- (void)busStationDetailWithSearchString:(NSString *)searchString;

/**
 *
 *  @brief  搜索关键词关联的公交路线
 *  @param  keyword 关键词
 *  @param  city    城市
 *  @param  pageNumger  页码
 *  @note   使用委托调用search: didReceivedBusLineResult:获得对应的结果
 *      
 */
- (void)busLinesWithKeyword:(NSString *)keyword inCity:(NSString *)city pageNumber:(NSUInteger)pageNumber;


/**
 *
 *  @brief  公交路线的详细信息
 *  @param  searchString 有MBBusStation中的searchString属性
 *  @note   使用委托调用search: didReceivedBusLineDetailResult:获得对应的结果
 *      
 */
- (void)busLineDetailWithSearchString:(NSString *)searchString;

/**
 *
 *  @brief  计算两个位置之间公交路线。
 *  @param  origin  原点位置，单位加密经纬度字符串
 *  @param  destination 目标位置,单位加密经纬度字符串
 *  @param  option  计算路线的参数
 *  @note   使用委托调用search: didReceivedTransitDirections:获得对应的结果
 *      
 */
- (void)transitDirectionsFromOrigin:(CLLocationCoordinate2D)origin toDestination:(CLLocationCoordinate2D)destination option:(MBTransitDirectionsOptions) option;

/**
 *
 *  @brief  计算两个位置之间公交路线。
 *  @param  searchString  MBTransitDirectiosResult对象返回的searchString
 *  @param  flag 是否计算步行数据
 *  @note   使用委托调用search: didReceivedTransitRoute:获得对应的结果
 *      
 */
- (void)transitRoute:(NSString *)searchString withWalkSteps:(BOOL)flag;

/**
 *
 *  @brief  计算两个位置之间步行路线。
 *  @param  origin  原点位置，单位加密经纬度字符串
 *  @param  destination 目标位置,单位加密经纬度字符串
 *  @param  option  计算路线的参数
 *  @note   使用委托调用search: didReceivedWalkDirections:获得对应的结果
 *      
 */
- (void)walkDirectionsFromOrigin:(CLLocationCoordinate2D)origin toDestination:(CLLocationCoordinate2D)destination option:(MBWalkDirectionsOptions) option;

/**
 *
 *  @brief  计算两个位置之间步行路线。
 *  @param  origin  原点位置，单位加密经纬度字符串
 *  @param  destination 目标位置,单位加密经纬度字符串
 *  @param  option  计算路线的参数
 *  @note   使用委托调用search: didReceivedDriveDirections:获得对应的结果
 *      
 */
- (void)driveDirectionsFromOrigin:(CLLocationCoordinate2D)origin toDestination:(CLLocationCoordinate2D)destination option:(MBDriveDirectionsOptions) option;

@end

@protocol MBSearchDelegate <NSObject>

@optional

/**
 *
 *  @brief  告知委托MBSearch对象成功的获取了建议关键词。
 *  @param  search    成功完成请求的MBSearch对象。
 *  @param  suggestResult   包含建议关键词数据的对象。
 *  @note  
 *  
 */
- (void)search:(MBSearch *)search didReceivedSuggestResult:(MBSuggestResult *)suggestResult;

/**
 *
 *  @brief  告知委托逆MBSearch对象成功的获取了路线建议关键词。
 *  @param  search    成功完成请求的MBSearch对象。
 *  @param  routeSuggestResult   包含路线建议关键词数据的对象。
 *  @note  
 *   
 */
- (void)search:(MBSearch *)search didReceivedRouteSuggestResult:(MBRouteSuggestResult *)routeSuggestResult;

/**
 *
 *  @brief  告知委托MBSearch对象成功的获取了Poi结果。
 *  @param  search    成功完成请求的MBSearch对象。
 *  @param  PoiResult   包含Poi结果的对象。
 *  @note  
 *  
 */
- (void)search:(MBSearch *)search didReceivedPoiResult:(MBPoiResult *)PoiResult;

/**
 *
 *  @brief  告知委托MBSearch对象成功的获取了公交站点结果。
 *  @param  search    成功完成请求的MBSearch对象。
 *  @param  busStationResult   包含公交站点结果的对象。
 *  @note  
 *    
 */
- (void)search:(MBSearch *)search didReceivedBusStationResult:(MBBusStationResult *)busStationResult;

/**
 *
 *  @brief  告知委托MBSearch对象成功的获取了公交站点详细结果。
 *  @param  search    成功完成请求的MBSearch对象。
 *  @param  busStationDetailResult   包含公交站点详细结果的对象。
 *  @note  
 *  
 */
- (void)search:(MBSearch *)search didReceivedBusStationDetailResult:(MBBusStationDetailResult *)busStationDetailResult;

/**
 *
 *  @brief  告知委托MBSearch对象成功的获取了公交路线结果。
 *  @param  search    成功完成请求的MBSearch对象。
 *  @param  busLineResult   包公交路线结果的对象。
 *  @note  
 *     
 */
- (void)search:(MBSearch *)search didReceivedBusLineResult:(MBBusLineResult *)busLineResult;

/**
 *
 *  @brief  告知委托MBSearch对象成功的获取了公交路线详细结果。
 *  @param  search    成功完成请求的MBSearch对象。
 *  @param  busLineDetailResult   包含公交路线详细结果的对象。
 *  @note  
 *  
 */
- (void)search:(MBSearch *)search didReceivedBusLineDetailResult:(MBBusLineDetailResult *)busLineDetailResult;

/**
 *
 *  @brief  告知委托MBSearch对象成功的获取了驾车路线。
 *  @param  search    成功完成请求的MBSearch对象。
 *  @param  driveDirctions   包含驾车路线的对象。
 *  @note  
 *    
 */
- (void)search:(MBSearch *)search didReceicedDriveDirections:(MBDriveDirections *)driveDirctions;

/**
 *
 *  @brief  告知委托MBSearch对象成功的获取了步行路线。
 *  @param  search    成功完成请求的MBSearch对象。
 *  @param  walkDirctions   包含步行路线的对象。
 *  @note  
 *    
 */
- (void)search:(MBSearch *)search didReceicedWalkDirections:(MBDirections *)walkDirctions;

/**
 *
 *  @brief  告知委托MBSearch对象成功的获取了公交路线。
 *  @param  search    成功完成请求的MBSearch对象。
 *  @param  walkDirctions   包含公交路线的对象。
 *  @note   返回的公交路线只有大致路线说明，没有详细的路线调用transitRoute:withWalkStep:获取具体的公交路线
 *    
 */
- (void)search:(MBSearch *)search didReceivedTransitDirections:(MBTransitDirections *)transitDirections;

/**
 *
 *  @brief  告知委托MBSearch对象成功的获取了步行路线。
 *  @param  search    成功完成请求的MBSearch对象。
 *  @param  transitRoute   包含公交路线的对象。
 *  @note  
 *    
 */
- (void)search:(MBSearch *)search didReceivedTransitRoute:(MBTransitRoute *)transitRoute;

/**
 *
 *  @brief  告知委托MBSearch未能完成请求。
 *  @param  search    未能完成请求的MBSearch对象。
 *  @param  error   表示请求未能成功原因的错误对象。
 *  @note  
 *    
 */
- (void)search:(MBSearch *)search didFailWithError:(NSError *)error;

@end
