//
//  MBTransitResult.h
//  MBMapkit_library
//
//  Created by 张嘉伟 on 11-10-26.
//  Copyright 2011 Mapbar Inc. All rights reserved.
//

//{{name:名称, lines:线路数, coordinate:坐标点, address:地址, more:更多},...}
//|1,站点名称|1,站点包含线路条数|0,1|1,地址|9,站点更多信息

#import <Foundation/Foundation.h>

#import "MBDirections.h"
#import "MBRoute.h"
#import "MBStep.h"

/** @interface MBTransitDirections
 *
 *  @brief
 *      MBTransitDirections对象表示返回公交路线的结果列表
 *     
 */
@interface MBTransitDirections : MBDirections

//NSString
@property (nonatomic, retain) NSArray *searchString;
@end

/** @interface MBTransitRoute
 *
 *  @brief
 *      MBTransitRoute对象表示公交路线结果中存储单条路线的信息
 *     
 */
@interface MBTransitRoute : MBRoute 
{
@private
    NSUInteger _numTransits;
}

/** @property   numTransits
 *
 *  @brief  包含此路程的换乘次数。
 */
@property (nonatomic, readonly) NSUInteger numTransits;
@end

/** @interface MBTransitStep
 *
 *  @brief
 *      MBTransitStep对象表示公交路线结果中存储一条路线中单个路段的信息
 *     
 */
@interface MBTransitStep : MBStep 
{
@private
    NSUInteger _numStops;
    NSUInteger _transitType;
    NSString *_startStation;
    NSString *_endStation;
}

/** @property   numStops
 *
 *  @brief  包含此路段的经过的站点数量。
 */
@property (nonatomic, readonly) NSUInteger numStops;

/** @property   transitType
 *
 *  @brief  包含此路段的交通方式。
 */
@property (nonatomic, readonly) NSUInteger transitType;

/** @property   startStation
 *
 *  @brief  包含此路段的上车站点。
 */
@property (nonatomic, readonly) NSString *startStation;

/** @property   endStation
 *
 *  @brief  包含此路段的下车站点。
 */
@property (nonatomic, readonly) NSString *endStation;

/** 
 *
 *  @brief 初始化MBTransitStep对象
 *  @param dictionary 包含MBTransitStep对象内容的数据字典
 *
 */
-(id)initWithDictionary:(NSDictionary *)dictionary;
@end